@@ -114,11 +114,9 @@ def main():
     ce_password = getpass.getpass(prompt="CommunityEdition(CE) password:")
     input_spec_one = input("Enter absolute path to Old API SPEC(Version A): ")
     input_spec_two = input("Enter absolute path to New API SPEC(Version B) : ")
-    ceobj = CommunityEdition("http://" + ce_host, ce_username, ce_password)
     if not os.path.exists(os.path.join(os.getcwd(), "my_cesetup.yaml")):
         with open(os.path.join(os.getcwd(), "my_cesetup.yaml"),"w+") as fobj:
-            yaml.dump({"ce_host":str(ce_host),"ce_username":str(ce_username) ,
-                       "ce_recording":str(ce_recording), "input_apispec":str(input_spec)},fobj)
+            yaml.dump({"ce_host":str(ce_host),"ce_username":str(ce_username)},fobj)
     CVTrafficRegenerator(input_spec_one,input_spec_two,ce_host,ce_username,ce_password)
 
 
